@@ -18,27 +18,24 @@
 #include "mainwindow.h"
 #include "trayicon.h"
 #include "invitationsrfbserver.h"
+#include "krfbconfig.h"
 
-#include <KAboutApplicationDialog>
 #include <KAboutData>
-#include <KAction>
-#include <KUniqueApplication>
-#include <KCmdLineArgs>
-#include <KDebug>
-#include <KLocale>
+#include <KDBusService>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KNotification>
 
-#include <QtGui/QPixmap>
-#include <QtGui/qwindowdefs.h>
-
-#ifdef KRFB_WITH_TELEPATHY_TUBES
-# include "tubesrfbserver.h"
-#endif
+#include <QDebug>
+#include <QPixmap>
+#include <qwindowdefs.h>
+#include <QX11Info>
 
 #include <signal.h>
 #include <X11/extensions/XTest.h>
+#include <QCommandLineParser>
+#include <QCommandLineOption>
 
+static const char KRFB_VERSION[] = I18N_NOOP("5.0");
 static const char description[] = I18N_NOOP("VNC-compatible server to share "
                                   "KDE desktops");
 
@@ -61,39 +58,48 @@ static bool checkX11Capabilities()
 
 int main(int argc, char *argv[])
 {
-    KAboutData aboutData("krfb", 0, ki18n("Desktop Sharing"), KDE_VERSION_STRING,
-                         ki18n(description), KAboutData::License_GPL,
-                         ki18n("(c) 2009-2010, Collabora Ltd.\n"
+    KAboutData aboutData(I18N_NOOP("krfb"),
+			 i18n("Desktop Sharing"),
+			 I18N_NOOP(KRFB_VERSION),
+                         i18n(description),
+			 KAboutLicense::GPL,
+                         i18n("(c) 2009-2010, Collabora Ltd.\n"
                                "(c) 2007, Alessandro Praduroux\n"
                                "(c) 2001-2003, Tim Jansen\n"
                                "(c) 2001, Johannes E. Schindelin\n"
                                "(c) 2000-2001, Const Kaplinsky\n"
                                "(c) 2000, Tridia Corporation\n"
                                "(c) 1999, AT&T Laboratories Boston\n"));
-    aboutData.addAuthor(ki18n("George Goldberg"),
-                        ki18n("Telepathy tubes support"),
+    aboutData.addAuthor(i18n("George Goldberg"),
+                        i18n("Telepathy tubes support"),
                         "george.goldberg@collabora.co.uk");
-    aboutData.addAuthor(ki18n("George Kiagiadakis"),
-                        KLocalizedString(),
+    aboutData.addAuthor(i18n("George Kiagiadakis"),
+                        QString(),
                         "george.kiagiadakis@collabora.co.uk");
-    aboutData.addAuthor(ki18n("Alessandro Praduroux"), ki18n("KDE4 porting"), "pradu@pradu.it");
-    aboutData.addAuthor(ki18n("Tim Jansen"), ki18n("Original author"), "tim@tjansen.de");
-    aboutData.addCredit(ki18n("Johannes E. Schindelin"),
-                        ki18n("libvncserver"));
-    aboutData.addCredit(ki18n("Const Kaplinsky"),
-                        ki18n("TightVNC encoder"));
-    aboutData.addCredit(ki18n("Tridia Corporation"),
-                        ki18n("ZLib encoder"));
-    aboutData.addCredit(ki18n("AT&T Laboratories Boston"),
-                        ki18n("original VNC encoders and "
+    aboutData.addAuthor(i18n("Alessandro Praduroux"), i18n("KDE4 porting"), "pradu@pradu.it");
+    aboutData.addAuthor(i18n("Tim Jansen"), i18n("Original author"), "tim@tjansen.de");
+    aboutData.addCredit(i18n("Johannes E. Schindelin"),
+                        i18n("libvncserver"));
+    aboutData.addCredit(i18n("Const Kaplinsky"),
+                        i18n("TightVNC encoder"));
+    aboutData.addCredit(i18n("Tridia Corporation"),
+                        i18n("ZLib encoder"));
+    aboutData.addCredit(i18n("AT&T Laboratories Boston"),
+                        i18n("original VNC encoders and "
                               "protocol design"));
-    KCmdLineArgs::init(argc, argv, &aboutData);
+    QApplication app(argc, argv);
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
-    KCmdLineOptions options;
-    options.add("nodialog", ki18n("Do not show the invitations management dialog at startup"));
-    KCmdLineArgs::addCmdLineOptions(options);
+    KDBusService service(KDBusService::Unique, &app);
+
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("nodialog"), i18n("Do not show the invitations management dialog at startup")));
 
-    KUniqueApplication app;
     app.setQuitOnLastWindowClosed(false);
 
     if (!checkX11Capabilities()) {
@@ -103,17 +109,15 @@ int main(int argc, char *argv[])
     //init the core
     InvitationsRfbServer::init();
 
-#ifdef KRFB_WITH_TELEPATHY_TUBES
-    TubesRfbServer::init();
-#endif
-
     //init the GUI
     MainWindow mainWindow;
     TrayIcon trayicon(&mainWindow);
 
-    if (app.isSessionRestored() && KMainWindow::canBeRestored(1)) {
+    if (KrfbConfig::startMinimized()) {
+      mainWindow.hide();
+    } else if (app.isSessionRestored() && KMainWindow::canBeRestored(1)) {
         mainWindow.restore(1, false);
-    } else if (KCmdLineArgs::parsedArgs()->isSet("dialog")) {
+    } else if (!parser.isSet("nodialog")) {
         mainWindow.show();
     }
 
@@ -124,4 +128,3 @@ int main(int argc, char *argv[])
 
     return app.exec();
 }
-
